pub struct DiscoveryResult {
pub backends: Vec<DiscoveredBackend>,
pub capability_models: Vec<ResolvedModel>,
}Expand description
Result of a discovery pass.
Fields
backends: Vec<DiscoveredBackend>capability_models: Vec<ResolvedModel>Final, deduplicated model list to send to the coordinator.
Implementations
Sourceimpl DiscoveryResult
impl DiscoveryResult
Sourcepub fn to_capabilities(&self, cfg: &Config) -> Value
pub fn to_capabilities(&self, cfg: &Config) -> Value
Build the capabilities wire message from this discovery result.